@@ -1,3 +1,5 @@
+# Håndterer al seriel kommunikation med micro:bit'en
+
 from time import sleep
 import serial
 from serial.tools.list_ports import comports
@@ -10,8 +12,9 @@ def send_message(msg):
     if ser is None:
         initialize_connection()
 
-    helper.printLog('m:b >>> ' + msg)
-    ser.write(bytes(msg, 'utf-8'))
+    msg_nl = msg + '\n'
+    helper.printLog('m:b >>> ' + msg_nl)
+    ser.write(bytes(msg_nl, 'utf-8'))
     # ensure that the controller do not pick up the message itself 
     sleep(0.2)
 
@@ -31,7 +34,6 @@ def initialize_connection():
         ser.reset_input_buffer()
         ser.reset_output_buffer()
         sleep(0.2)
-        send_message('init')
         return ser
     except Exception as e:
         print()
